==> alipay_sdk_python-3.6.733-py3-none-any.whl: alipay/aop/api/response/AlipayCloudCloudbaseDatabaseTaskQueryResponse.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FaasDatabaseHistorie import FaasDatabaseHistorie


class AlipayCloudCloudbaseDatabaseTaskQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCloudCloudbaseDatabaseTaskQueryResponse, self).__init__()
        self._histories = None
        self._page_index = None
        self._page_size = None
        self._total = None

    @property
    def histories(self):
        return self._histories

    @histories.setter
    def histories(self, value):
        if isinstance(value, list):
            self._histories = list()
            for i in value:
                if isinstance(i, FaasDatabaseHistorie):
                    self._histories.append(i)
                else:
                    self._histories.append(FaasDatabaseHistorie.from_alipay_dict(i))
    @property
    def page_index(self):
        return self._page_index

    @page_index.setter
    def page_index(self, value):
        self._page_index = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(AlipayCloudCloudbaseDatabaseTaskQueryResponse, self).parse_response_content(response_content)
        if 'histories' in response:
            self.histories = response['histories']
        if 'page_index' in response:
            self.page_index = response['page_index']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total' in response:
            self.total = response['total']

==> alipay_sdk_python-3.7.78-py3-none-any.whl: alipay/aop/api/response/AlipayCloudCloudbaseDatabaseTaskQueryResponse.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MongoTaskHistory import MongoTaskHistory


class AlipayCloudCloudbaseDatabaseTaskQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCloudCloudbaseDatabaseTaskQueryResponse, self).__init__()
        self._page_index = None
        self._page_size = None
        self._tasks = None
        self._total = None

    @property
    def page_index(self):
        return self._page_index

    @page_index.setter
    def page_index(self, value):
        self._page_index = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def tasks(self):
        return self._tasks

    @tasks.setter
    def tasks(self, value):
        if isinstance(value, list):
            self._tasks = list()
            for i in value:
                if isinstance(i, MongoTaskHistory):
                    self._tasks.append(i)
                else:
                    self._tasks.append(MongoTaskHistory.from_alipay_dict(i))
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(AlipayCloudCloudbaseDatabaseTaskQueryResponse, self).parse_response_content(response_content)
        if 'page_index' in response:
            self.page_index = response['page_index']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'tasks' in response:
            self.tasks = response['tasks']
        if 'total' in response:
            self.total = response['total']
